﻿create sequence seq_raum;
create sequence seq_geraet;
CREATE TABLE Mitarbeiter(
	SVNR NUMBER PRIMARY KEY, 
	name VARCHAR2(20) NOT NULL,
	Adresse VARCHAR2(40) NOT NULL,
	Telefon VARCHAR2(10),
	EintrittsDat DATE NOT NULL);
CREATE TABLE Administration(
	SVNR NUMBER PRIMARY KEY REFERENCES Mitarbeiter(SVNR),
	Funktion VARCHAR2(40));
CREATE TABLE Trainer(
	SVNR NUMBER PRIMARY KEY REFERENCES Mitarbeiter(SVNR),
	Ausbildung VARCHAR2(40),
	Stundensatz NUMBER(7,2));
CREATE TABLE Standort(
	NR NUMBER NOT NULL,
	Strasse VARCHAR2(100) NOT NULL,
	PLZ NUMBER, 
	Ort VARCHAR2(30),
	PRIMARY KEY (NR, Strasse)
);
CREATE TABLE Fitnesscenter(
	NR NUMBER NOT NULL,
	Strasse VARCHAR2(100) NOT NULL,
	Name VARCHAR2(50), 
	Email VARCHAR2(50),
	TelNr VARCHAR2(10),
	Leiter REFERENCES Mitarbeiter(SVNR),
	PRIMARY KEY (NR, Strasse),
	CONSTRAINT fk_FC
	FOREIGN KEY (NR, Strasse) REFERENCES Standort(NR, Strasse)
);
CREATE TABLE Arbeitet(
	SVNR NUMBER NOT NULL,
	FCNr NUMBER NOT NULL,
	FCStrasse VARCHAR2(100) NOT NULL,
	FOREIGN KEY (SVNR) REFERENCES Mitarbeiter(SVNR),
	FOREIGN KEY (FCNr, FCStrasse) REFERENCES Fitnesscenter(NR, Strasse),
	PRIMARY KEY (SVNR, FCNr, FCStrasse)
);
CREATE TABLE Raum(
	RNr NUMBER,
	FCNr NUMBER,
	FCStrasse VARCHAR2(100),
	Name VARCHAR2(50),
	Kapazitaet NUMBER,
	FOREIGN KEY (FCNr, FCStrasse) REFERENCES Fitnesscenter(NR, Strasse),
	PRIMARY KEY (RNr, FCNr, FCStrasse)
);
CREATE TABLE Geraet(
	SNr NUMBER PRIMARY KEY, 
	Beschreibung VARCHAR2(100),
	name VARCHAR2(50) NOT NULL,
	AnschaffDat DATE NOT NULL,
	Garantie NUMBER
);
CREATE TABLE ist_im(
	SNr NUMBER,
	RNr NUMBER,
	FCNr NUMBER,
	FCStrasse VARCHAR2(100),
	FOREIGN KEY (SNr) REFERENCES Geraet(SNr),
	FOREIGN KEY (RNr, FCNr, FCStrasse) REFERENCES Raum(RNr, FCNr, FCStrasse),
	PRIMARY KEY (SNr)
);
CREATE TABLE Kurs(
	KNr NUMBER PRIMARY KEY,
	Bezeichnung VARCHAR2(100),
	Beginn DATE,
	Ende DATE,
	Datum DATE
);
CREATE TABLE ist_nachfolger_von(
	nachfolger NUMBER REFERENCES Kurs(KNr),
	vorgaenger NUMBER REFERENCES Kurs(KNr),
	CHECK(nachfolger <> vorgaenger),
	PRIMARY KEY (nachfolger, vorgaenger)
);
CREATE TABLE Abhaltung(
	Trainer NUMBER,
	KursNr NUMBER,
	RaumRNr NUMBER,
	RaumFCNr NUMBER,
	RaumFCStrasse VARCHAR2(100),
	FOREIGN KEY (Trainer) REFERENCES Trainer(SVNR),
	FOREIGN KEY (KursNr) REFERENCES Kurs(KNr),
	FOREIGN KEY (RaumRNr, RaumFCNr, RaumFCStrasse) REFERENCES Raum(RNr, FCNr, FCStrasse),
	PRIMARY KEY (Trainer,KursNr,RaumRNr, RaumFCNr, RaumFCStrasse)
);
CREATE TABLE Kunde(
	KNr NUMBER PRIMARY KEY,
	VName VARCHAR2(50) NOT NULL,
	NName VARCHAR2(50) NOT NULL,
	GebDat DATE,
	Adresse VARCHAR2(100),
	Telefon VARCHAR2(30)
);
CREATE TABLE Abonnement(
	KNr NUMBER REFERENCES Kunde(KNr),
	AblaufDat DATE,
	PRIMARY KEY (KNr)
);
CREATE TABLE teilnehmen(
	KundenNr NUMBER REFERENCES Kunde(KNr),
	KursNr NUMBER REFERENCES Kurs(KNr),
	PRIMARY KEY (KundenNr, KursNr)
);
CREATE TABLE Einzeltraining(
	Trainer NUMBER REFERENCES Trainer(SVNR),
	KundenNr NUMBER REFERENCES Kunde(KNr),
	Schwerpunkt VARCHAR2(50),
	PRIMARY KEY (Trainer, KundenNr)
);